@@ -8,7 +8,7 @@ use WWW::Crawler::Mojo::UserAgent;
 use Mojo::Message::Request;
 use Mojo::Util qw{md5_sum xml_escape dumper};
 use List::Util;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 has active_conn => 0;
 has depth => 10;
@@ -93,13 +93,12 @@ sub process_job {
         my $res = $tx->res;
         
         if (!$res->code) {
-            my $msg = ($res->error) ? $res->error->{message} : 'Unknown error';
-            my $url = $job->resolved_uri;
-            $self->emit('error', $msg, $job);
+            $self->emit('error',
+                ($res->error) ? $res->error->{message} : 'Unknown error', $job);
             return;
         }
         
-        $self->emit('res', sub { $self->browse($res, $job) }, $job, $res);
+        $self->emit('res', sub { $self->scrape($res, $job) }, $job, $res);
     });
 }
 
@@ -150,7 +149,7 @@ sub peeping_handler {
     });
 }
 
-sub browse {
+sub scrape {
     my ($self, $res, $job) = @_;
     
     return if ($res->code != 200);
@@ -360,16 +359,14 @@ WWW::Crawler::Mojo - A web crawling framework for Perl
 
     use strict;
     use warnings;
-    use utf8;
     use WWW::Crawler::Mojo;
-    use 5.10.0;
     
     my $bot = WWW::Crawler::Mojo->new;
     
     $bot->on(res => sub {
-        my ($bot, $browse, $job, $res) = @_;
+        my ($bot, $scrape, $job, $res) = @_;
         
-        $browse->();
+        $scrape->();
     });
     
     $bot->on(refer => sub {
@@ -489,9 +486,9 @@ implements the following new ones.
 Emitted when crawler got response from server.
 
     $bot->on(res => sub {
-        my ($bot, $browse, $job, $res) = @_;
+        my ($bot, $scrape, $job, $res) = @_;
         if (...) {
-            $browse->();
+            $scrape->();
         } else {
             # DO NOTHING
         }
@@ -582,11 +579,11 @@ peeping API dispatcher.
 
     $bot->peeping_handler($loop, $stream);
 
-=head2 browse
+=head2 scrape
 
 Parses and discovers links in a web page. Each links are appended to FIFO array.
 
-    $bot->browse($res, $job);
+    $bot->scrape($res, $job);
 
 =head2 enqueue
 
